@@ -1,8 +1,6 @@
 import logging
 from adaendra_immutable_dict.AdaendraImmutableDict import AdaendraImmutableDict
 
-from adaendra_python_config_loader.AdaendraConfigsLoader import load_configs
-
 
 class AdaendraConfigs(object):
     """
@@ -14,27 +12,25 @@ class AdaendraConfigs(object):
 
     # --- METHODS
     def __init__(self):
-        logging.info('--1--')
-        AdaendraConfigs.configs = AdaendraConfigs.__AdaendraConfigs(load_configs())
+        logging.error('--__init__--')
 
     def __new__(cls, config_dict: dict):
-        logging.info('--2--')
+        logging.error('--__new__--')
         if not AdaendraConfigs.configs:
             AdaendraConfigs.configs = AdaendraConfigs.__AdaendraConfigs(config_dict)
         return AdaendraConfigs.configs
 
     def __getattr__(self, name):
-        logging.info('--3--')
+        logging.error('--__getattr__--')
         if not AdaendraConfigs.configs:
-            AdaendraConfigs.configs = AdaendraConfigs.__AdaendraConfigs(load_configs())
             raise AttributeError(
                 f"No configs were loaded on start."
             )
         return getattr(self.configs, name)
 
     def __getattribute__(self, name):
+        logging.error('--__getattribute__--')
         if not AdaendraConfigs.configs:
-            AdaendraConfigs.configs = AdaendraConfigs.__AdaendraConfigs(load_configs())
             raise AttributeError(
                 f"No configs were loaded on start."
             )
@@ -66,4 +62,4 @@ class AdaendraConfigs(object):
             return self.configs_dict[name]
 
 
-__all__ = (AdaendraConfigs.__name__,)
\ No newline at end of file
+__all__ = (AdaendraConfigs.__name__,)
